@@ -1,5 +1,5 @@
 package PostScript::File;
-our $VERSION = 0.13;
+our $VERSION = 1.01;
 use strict;
 use warnings;
 use File::Spec;
@@ -12,7 +12,6 @@ our @EXPORT_OK = qw(check_tilde check_file incpage_label incpage_roman array_as_
 # Prototypes for functions only
  sub incpage_label ($);
  sub incpage_roman ($);
- sub print_file ($$);
  sub check_tilde ($); 
  sub check_file ($;$$);
 
@@ -214,8 +213,7 @@ our @fonts = qw(
 
 =cut
 
-sub new
-{
+sub new {
     my ($class, @options) = @_;
     my $opt = {};
     if (@options == 1) {
@@ -224,6 +222,7 @@ sub new
 	%$opt = @options;
     }
     
+    ## Initialization
     my $o = {
 	# postscript DSC sections
 	Comments    => "",  # must include leading '%%' and end with '\n'
@@ -252,6 +251,9 @@ sub new
     };
     bless $o, $class;
 
+    ## Paper layout
+    $o->{png}	= defined($opt->{png})	? $opt->{png}  : 0;
+    $o->{gs}	= defined($opt->{gs})	? $opt->{gs}   : 'gs';
     $o->{eps}	= defined($opt->{eps})	? $opt->{eps}  : 0;
     $o->{file}	= defined($opt->{file})	? $opt->{file} : "";
     $o->{dir}	= defined($opt->{dir})	? $opt->{dir}  : "";
@@ -260,6 +262,7 @@ sub new
     $o->set_height( $opt->{height} );
     $o->set_landscape( $opt->{landscape} );
     
+    ## Debug options
     $o->{debug} = $opt->{debug};	# undefined is an option
     if ($o->{debug}) {
 	$o->{db_active}   = $opt->{db_active}   || 1;
@@ -274,6 +277,7 @@ sub new
 	$o->{db_color}    = $opt->{db_color}    || "0 setgray";
     }
    
+    ## Bounding box
     my $x0 = $o->{bbox}[0] + ($opt->{left} || 28); 
     my $y0 = $o->{bbox}[1] + ($opt->{bottom} || 28); 
     my $x1 = $o->{bbox}[2] - ($opt->{right} || 28);
@@ -281,6 +285,7 @@ sub new
     $o->set_bounding_box( $x0, $y0, $x1, $y1 );
     $o->set_clipping( $opt->{clipping} || 0 );
     
+    ## Other options
     $o->{title}	     = defined($opt->{title})	     ? $opt->{title}	    : undef;
     $o->{version}    = defined($opt->{version})	     ? $opt->{version}      : undef;
     $o->{langlevel}  = defined($opt->{langlevel})    ? $opt->{langlevel}    : undef;
@@ -304,6 +309,7 @@ sub new
    
     $o->newpage( $o->get_page_label() );
     
+    ## Finish
     return $o;
 }
 
@@ -1119,7 +1125,7 @@ END_DEBUG_END
 	    $postscript .= "$debugend\n";
 	    $postscript .= $o->post_pages(); 
 
-	    print_file( $epsfile, $postscript );
+	    $o->print_file( $epsfile, $postscript );
 	    
 	    $p++;
 	} while ($p < $o->{pagecount});
@@ -1167,7 +1173,7 @@ END_PAGE_SETUP
 END_PAGE_TRAILER
 	}
 	$postscript .= $o->post_pages();
-	return print_file( $psfile, $postscript );
+	return $o->print_file( $psfile, $postscript );
     }
 }
 
@@ -1181,6 +1187,29 @@ can still be extended.
 
 =cut
 
+
+sub print_file {
+    my ($o, $filename, $contents) = @_;
+    if ($filename) {
+	open(OUTFILE, ">", $filename) or die "Unable to write to \'$filename\' : $!\nStopped";
+	print OUTFILE $contents;
+	close OUTFILE;
+
+	if ($o->{png}) {
+	    my $psfile  = "$filename.ps";
+	    my $gs      = $o->get_ghostscript();
+	    my $pngfile = check_file("$o->{filename}.png", $o->{directory});
+	    my @cmd = qq(cat $filename | $gs -q -dBATCH -sDEVICE=png16m -sOutputFile=$pngfile -);
+	    system @cmd;
+	    unlink $filename;
+	}
+    } else {
+	return "$contents\n";
+    }
+}
+# Internal method, used by output()
+# Expects file name and contents
+
 =head1 ACCESS METHODS
 
 Use these B<get_> and B<set_> methods to access a PostScript::File object's data. 
@@ -1640,6 +1669,18 @@ Retrieve a user defined value.
 
 =cut
 
+
+sub get_ghostscript {
+    my $o = shift;
+    return defined($o->{ghostscript}) ? $o->{ghostscript} : 'gs'; 
+}
+
+=head2 get_ghostscript
+
+Return the ghostscript interpreter that would be used to output a Portable Network Graphics file.
+
+=cut
+
 =head1 CONTENT METHODS
 
 =cut
@@ -2130,21 +2171,6 @@ sub clip_bounding_box {
     $o->{clipcmd} = "clip"; 
 }
 
-### PRIVATE FUNCTIONS
-
-sub print_file ($$) {
-    my($filename, $contents) = @_;
-    if ($filename) {
-	open(OUTFILE, ">", $filename) or die "Unable to write to \'$filename\' : $!\nStopped";
-	print OUTFILE $contents;
-	close OUTFILE;
-    } else {
-	return "$contents\n";
-    }
-}
-# Internal function, used by output()
-# Expects file name and contents
-
 =head1 EXPORTED FUNCTIONS
 
 No functions are exported by default, they must be named as required.
